==> moodle-1.4.3.tgz: moodle/lang/th/survey.php <==
<?PHP // $Id$ 
      // survey.php - created with Moodle 1.4 development (2004060400)


$string['actual'] = 'ԧ';
$string['actualclass'] = '͹ԧ';
$string['actualstudent'] = '$a ԧ';
$string['allquestions'] = 'Ӷ§ ӴѺ ѡ¹ء';
$string['allscales'] = 'ء  ѡ¹ء';
$string['alreadysubmitted'] = 'سẺͺ';
$string['analysisof'] = 'ͧ $a';
$string['answers'] = 'ӵͺ';
$string['attls1'] = '㹡õѴԹ觷ͺͺҹ  ٷ˹ѡ ͧ ͺͺ 繤ͺ';
$string['attls10'] = 'ҧ觷ҧ繡ҧ͵ͧ';
$string['attls10short'] = 'ҧ繡ҧ';
$string['attls11'] = 'ФԴͺ ᷹ФԴ';
$string['attls11short'] = 'Դͺ';
$string['attls12'] = ' criteria ͹㹡õѴԹҤӵͺ';
$string['attls12short'] = '  criteria 㹡õѴԹ';
$string['attls13'] = '㨤Դ繢ͧҡҵѴԹѹ';
$string['attls13short'] = '';
$string['attls14'] = 'ͺ繶֧شͧ觷赹ͧԴ ͪͺͧҾ觷赹ͧͺ仪Ѵਹ';
$string['attls14short'] = '繨شͧ';
$string['attls15'] = 'ԴҶ繺ؤŹաԻͧ з Ҷ֧Դҧ';
$string['attls15short'] = 'ԴҶҨзҧ';
$string['attls16'] = 'Ԩóҷءҧҹ ҧѴѧ';
$string['attls16short'] = 'Ԩóѡҹءҧ';
$string['attls17'] = 'Ӥѭ á  ˵ؼ ҡ Դͧͧ㹡ѭ';
$string['attls17short'] = 'Ӥѭá';
$string['attls18'] = 'žԹԨͤԴ繢ͧ蹹鹵ҧҡͧҧ֡';
$string['attls18short'] = '÷Ӥҧ֡';
$string['attls19'] = 'ͩѹͧ༪ԭѺդ繷ᵡҧҡͧ ѹͧ оҶ֧ ֡ҷҨ֧Դҧ';
$string['attls19short'] = 'Ӥ';
$string['attls1short'] = 'Ҩش˭㨤͡駡ѹ';
$string['attls2'] = 'ѹеǹ㹷ء¤Ӣͧ';
$string['attls20'] = 'ѹͧüԴҴҧ  ѹͧ͡ѹҢ駹ѧվ';
$string['attls20short'] = 'üԴ';
$string['attls2short'] = 'ӵ繤觵ǩҨ';
$string['attls3'] = 'ӤҤҨҡ˹ ջʺó ֧֡蹹';
$string['attls3short'] = '鹰ҹͧФ';
$string['attls4'] = '觷Ӥѭش㹡֡ ͡¹㨼餹ᵡҧ';
$string['attls4short'] = '㨶֧Ѩਡ';
$string['attls5'] = 'ҧշشкؤ͡ѡɳͧͧ  ûѹѺ餹ҡ';
$string['attls5short'] = 'ѹѺҡ';
$string['attls6'] = '֡դآѺѧԴ繨ҡ餹վ鹰ҹᵡҧ Шзͧͧᵡҧ';
$string['attls6short'] = 'դآѺѧԴ';
$string['attls7'] = '֡秢鹨ҡö§Ѻҧ繴';
$string['attls7short'] = '֡秢鹨ҡö§';
$string['attls8'] = '֡ʹ˵ط餹ٴ觷ҷ';
$string['attls8short'] = '˵ط餹';
$string['attls9'] = 'ͺ§Ѻ¹˹ѧ ͪ˵آͧͼԴҴ';
$string['attls9short'] = '§Ѻ¹';
$string['attlsintro'] = 'Ẻͺըشʧͪ㹡ûԹȹԵ͡äԴ С¹

դӵͺ ١  Դ оԨó੾ФԴҹ鹤ӵͺͧҹж١繤Ѻ Шռŵ͡ûԹͧҹ';
$string['attlsm1'] = 'ȹԵ͡äԴ С¹';
$string['attlsm2'] = '¹§';
$string['attlsm3'] = '¹¡ǹ';
$string['attlsmintro'] = '㹡ö...';
$string['attlsname'] = 'ATTLS ( 20 Ӷ)';
$string['ciq1'] = '㹰ҹм¹ سͺҹǹ˹شͧԪҹ?';
$string['ciq1short'] = 'Ǣͧش';
$string['ciq2'] = '㹰ҹм¹ سҹǹ˹شͧԪҹ?';
$string['ciq2short'] = 'Ƿش';
$string['ciq3'] = 'áз㴢ͧؤ㹡дҹǹҷس繻ªЪͤسҡش?';
$string['ciq3short'] = 'ҷ繻ª';
$string['ciq4'] = 'áз㴢ͧؤ㹡дҹǹ سҷسѺʹǷش?';
$string['ciq4short'] = 'ҷѺʹ';
$string['ciq5'] = '˵ءó㴷سзѺ㨷ش?';
$string['ciq5short'] = 'ҷš';
$string['ciqintro'] = 'ôͺӶҧҧ';
$string['ciqname'] = '˵ءóԡĵ';
$string['clicktocontinue'] = ' ͷӵ';
$string['clicktocontinuecheck'] = '͵Ǩ зӵ';
$string['colles1'] = '¹鹻繷ʹ繡ǹ';
$string['colles10'] = 'ѡ¹蹢ǤԴ';
$string['colles10short'] = 'ͤ͸Ժ';
$string['colles11'] = 'ѡ¹蹢ѹǤԴ';
$string['colles11short'] = 'դѩѹ͸Ժ';
$string['colles12'] = 'ѡ¹蹵ͺѺԴ';
$string['colles12short'] = 'ѡ¹蹵ͺѺѹ';
$string['colles13'] = '͹¡е鹤Դ';
$string['colles13short'] = '͹¡е鹤Դ';
$string['colles14'] = '͹ʹѺʹعǹ';
$string['colles14short'] = '͹ʹѺʹعǹ';
$string['colles15'] = '͹͡Ẻʹ';
$string['colles15short'] = '͹͡Ẻʹ';
$string['colles16'] = '͹͡ẺԨͧ';
$string['colles16short'] = '͹͡ẺԨͧ';
$string['colles17'] = 'ѡ¹ʹѺʹعǹ';
$string['colles17short'] = 'ѡ¹ʹѺʹع';
$string['colles18'] = 'ѡ¹¡ͧ';
$string['colles18short'] = 'ѡ¹¡ͧ';
$string['colles19'] = 'ѡ¹繤سҢͧ';
$string['colles19short'] = 'ѡ¹繤س';
$string['colles1short'] = '㹻繷ʹ';
$string['colles2'] = '觷¹ դӤѭ͡ý֡ԪҪվ';
$string['colles20'] = 'ѡ¹㹤';
$string['colles20short'] = 'ѡ¹';
$string['colles21'] = 'ѹͷѡ¹蹹ʹ';
$string['colles21short'] = 'ѹ㨹ѡ¹';
$string['colles22'] = 'ѡ¹ͷʹ';
$string['colles22short'] = 'ѡ¹㨩ѹ';
$string['colles23'] = 'ѹͷ͹ʹ';
$string['colles23short'] = 'ѹ㨼͹';
$string['colles24'] = '͹ͷʹ';
$string['colles24short'] = '͹㨩ѹ';
$string['colles2short'] = 'Ӥѭ͡ý֡Ѵ';
$string['colles3'] = '觷¹դӤѭ͡ý֡ԪҪվ';
$string['colles3short'] = 'Ѳҡý֡Ѵ';
$string['colles4'] = '觷¹ ǹǢͧѺý֡ԪҪվ';
$string['colles4short'] = 'ǢͧѺý֡ԪҪվ';
$string['colles5'] = 'ԴҡͧԸա¹';
$string['colles5short'] = '´㹡¹';
$string['colles6'] = 'ԴҡͧԴǹ';
$string['colles6short'] = '´㹤ǹ';
$string['colles7'] = 'ԴҡͧԴ繢ͧѡ¹';
$string['colles7short'] = '´ͧѡ¹';
$string['colles8'] = '´ͧԴ觷ҹ';
$string['colles8short'] = '´觷ҹ';
$string['colles9'] = '͸Ժ¤Դǹѡ¹';
$string['colles9short'] = '͸Ժ¤Դǹ';
$string['collesaintro'] = 'Ǩըشʧͪ͡͹͹ŹЪҹ¹§

Ӷ 24 ͵仹 жͧʺóҡ÷ͧҹѧ

դӵͺ ١  Դ оԨó੾ФԴҹ鹤ӵͺͧҹж١繤Ѻ Шռŵ͡ûԹͧҹ

ӵͺͧҹǹ¾ѲٻẺͧ͡¹͹͹Ź͹Ҥ

ͺسҡ';
$string['collesaname'] = 'COLLES (Actual)';
$string['collesapintro'] = 'Ǩըشʧͪ͡͹͹ŹЪҹ¹§

Ӷ 24 ͵仹 жºº֧ <B>ͺ<B> (㹤Դ)  <B>֡ԧ<B> ҡ÷ͧҹ

դӵͺ ١  Դ оԨó੾ФԴҹ鹤ӵͺͧҹж١繤Ѻ Шռŵ͡ûԹͧҹ

ӵͺͧҹǹ¾ѲٻẺͧ͡¹͹͹Ź͹Ҥ

ͺسҡ';
$string['collesapname'] = 'COLLES (Preferred and Actual)';
$string['collesm1'] = 'Ǣͧ';
$string['collesm1short'] = 'Ǣͧ';
$string['collesm2'] = 'Ԩͧ';
$string['collesm2short'] = 'Ԩͧ';
$string['collesm3'] = 'Ԩѹ';
$string['collesm3short'] = 'Ԩѹ';
$string['collesm4'] = 'ͨҡ͹';
$string['collesm4short'] = 'ͨҡ͹';
$string['collesm5'] = 'ǢͧʹѺʹع';
$string['collesm5short'] = 'Ǣͧ';
$string['collesm6'] = '';
$string['collesm6short'] = '';
$string['collesmintro'] = '㹺¹͹Ź';
$string['collespintro'] = 'Ǩըشʧͪ㨤سҢͧʺó㹡¹ͤ͹

Ӷ 24 ͵仹 жǡѺ <B>ͺ</B>㹡õͺẺͺ

դӵͺ ١  Դ оԨó੾ФԴҹ鹤ӵͺͧҹж١繤Ѻ Шռŵ͡ûԹͧҹ

ӵͺͧҹǹ¾ѲٻẺͧ͡¹͹͹Ź͹Ҥ

ͺسҡ';
$string['collespname'] = 'COLLES (Preferred)';
$string['done'] = '';
$string['download'] = 'ǹŴ';
$string['downloadexcel'] = 'ǹŴٻ ҧ Excel';
$string['downloadinfo'] = 'ҹöǹŴŴԺҡẺͺ ͡ ٻͧ Excel, SPSS ';
$string['downloadtext'] = 'ǹŴٻͧ  plain text';
$string['editingasurvey'] = 'Ẻͺ';
$string['guestsnotallowed'] = '੾Ҫԡҹ';
$string['helpsurveys'] = 'ǡѺ Ẻͺ';
$string['howlong'] = 'ҹҹҹ㹡÷Ẻͺ';
$string['howlongoptions'] = '¡ 1 ҷ, 1-2 ҷ, 2-3 ҷ, 3-4 ҷ, 4-5 ҷ, 5-10 ҷ, ҡ 10 ҷ';
$string['ifoundthat'] = 'ѹ';
$string['introtext'] = 'ͤʴͧ';
$string['ipreferthat'] = 'ѹͺҡҷ';
$string['modulename'] = 'Ẻͺ';
$string['modulenameplural'] = 'Ẻͺ';
$string['name'] = '';
$string['newsurveyresponses'] = 'šǨ ';
$string['nobodyyet'] = 'ռ㴷Ẻͺ';
$string['notdone'] = 'ѧ';
$string['notes'] = 'кѹ֡ͧҹ';
$string['othercomments'] = 'Դ';
$string['peoplecompleted'] = ' $a    Ẻͺ';
$string['preferred'] = 'ͺ';
$string['preferredclass'] = '¹ͺ';
$string['preferredstudent'] = '$a  ͺ';
$string['question'] = 'Ӷ';
$string['questions'] = 'Ӷ';
$string['questionsnotanswered'] = 'Ӷҧѧͺ';
$string['report'] = '§ҹǨ';
$string['savednotes'] = 'Ţͧҹ١ѹ֡';
$string['scaleagree5'] = '繴ҧ, 繴, դ, 繴, 繴ҧ';
$string['scales'] = '';
$string['scaletimes5'] = 'ͺ, ҡ, ҧ, , ͺʹ ';
$string['seemoredetail'] = ' ҹ´';
$string['selectedquestions'] = 'Ӷ١͡ҡ ѡ¹';
$string['summary'] = 'Ѵ';
$string['surveycompleted'] = 'سẺͺ ҿҧҧʴººѺ¢ͧ¹';
$string['surveyname'] = '͡Ǩ';
$string['surveysaved'] = 'Ǩѹ֡';
$string['surveytype'] = 'Ǩ';
$string['thanksforanswers'] = 'ͺسѺõͺẺͺ, $a';
$string['time'] = '';
$string['viewsurveyresponses'] = ' $a šǨ';

?>

==> moodle-1.5.tgz: moodle/lang/th/survey.php <==
<?PHP // $Id$ 
      // survey.php - created with Moodle 1.6 development (2005052400)


$string['actual'] = 'ԧ';
$string['actualclass'] = '͹ԧ';
$string['actualstudent'] = '$a ԧ';
$string['allquestions'] = 'Ӷ§ ӴѺ ѡ¹ء';
$string['allscales'] = 'ء  ѡ¹ء';
$string['alreadysubmitted'] = 'سẺͺ';
$string['analysisof'] = 'ͧ $a';
$string['answers'] = 'ӵͺ';
$string['attls1'] = '㹡õѴԹ觷ͺͺҹ  ٷ˹ѡ ͧ ͺͺ 繤ͺ';
$string['attls10'] = 'ҧ觷ҧ繡ҧ͵ͧ';
$string['attls10short'] = 'ҧ繡ҧ';
$string['attls11'] = 'ФԴͺ ᷹ФԴ';
$string['attls11short'] = 'Դͺ';
$string['attls12'] = ' criteria ͹㹡õѴԹҤӵͺ';
$string['attls12short'] = '  criteria 㹡õѴԹ';
$string['attls13'] = '㨤Դ繢ͧҡҵѴԹѹ';
$string['attls13short'] = '';
$string['attls14'] = 'ͺ繶֧شͧ觷赹ͧԴ ͪͺͧҾ觷赹ͧͺ仪Ѵਹ';
$string['attls14short'] = '繨شͧ';
$string['attls15'] = 'ԴҶ繺ؤŹաԻͧ з Ҷ֧Դҧ';
$string['attls15short'] = 'ԴҶҨзҧ';
$string['attls16'] = 'Ԩóҷءҧҹ ҧѴѧ';
$string['attls16short'] = 'Ԩóѡҹءҧ';
$string['attls17'] = 'Ӥѭ á  ˵ؼ ҡ Դͧͧ㹡ѭ';
$string['attls17short'] = 'Ӥѭá';
$string['attls18'] = 'žԹԨͤԴ繢ͧ蹹鹵ҧҡͧҧ֡';
$string['attls18short'] = '÷Ӥҧ֡';
$string['attls19'] = 'ͩѹͧ༪ԭѺդ繷ᵡҧҡͧ ѹͧ оҶ֧ ֡ҷҨ֧Դҧ';
$string['attls19short'] = 'Ӥ';
$string['attls1short'] = 'Ҩش˭㨤͡駡ѹ';
$string['attls2'] = 'ѹеǹ㹷ء¤Ӣͧ';
$string['attls20'] = 'ѹͧüԴҴҧ  ѹͧ͡ѹҢ駹ѧվ';
$string['attls20short'] = 'üԴ';
$string['attls2short'] = 'ӵ繤觵ǩҨ';
$string['attls3'] = 'ӤҤҨҡ˹ ջʺó ֧֡蹹';
$string['attls3short'] = '鹰ҹͧФ';
$string['attls4'] = '觷Ӥѭش㹡֡ ͡¹㨼餹ᵡҧ';
$string['attls4short'] = '㨶֧Ѩਡ';
$string['attls5'] = 'ҧշشкؤ͡ѡɳͧͧ  ûѹѺ餹ҡ';
$string['attls5short'] = 'ѹѺҡ';
$string['attls6'] = '֡դآѺѧԴ繨ҡ餹վ鹰ҹᵡҧ Шзͧͧᵡҧ';
$string['attls6short'] = 'դآѺѧԴ';
$string['attls7'] = '֡秢鹨ҡö§Ѻҧ繴';
$string['attls7short'] = '֡秢鹨ҡö§';
$string['attls8'] = '֡ʹ˵ط餹ٴ觷ҷ';
$string['attls8short'] = '˵ط餹';
$string['attls9'] = 'ͺ§Ѻ¹˹ѧ ͪ˵آͧͼԴҴ';
$string['attls9short'] = '§Ѻ¹';
$string['attlsintro'] = 'Ẻͺըشʧͪ㹡ûԹȹԵ͡äԴ С¹

դӵͺ &#8220;١&#8221;  &#8220;Դ&#8221; оԨó੾ФԴҹ鹤ӵͺͧҹж١繤Ѻ Шռŵ͡ûԹͧҹ';
$string['attlsm1'] = 'ȹԵ͡äԴ С¹';
$string['attlsm2'] = '¹§';
$string['attlsm3'] = '¹¡ǹ';
$string['attlsmintro'] = '㹡ö...';
$string['attlsname'] = 'ATTLS ( 20 Ӷ)';
$string['ciq1'] = '㹰ҹм¹ سͺҹǹ˹شͧԪҹ?';
$string['ciq1short'] = 'Ǣͧش';
$string['ciq2'] = '㹰ҹм¹ سҹǹ˹شͧԪҹ?';
$string['ciq2short'] = 'Ƿش';
$string['ciq3'] = 'áз㴢ͧؤ㹡дҹǹҷس繻ªЪͤسҡش?';
$string['ciq3short'] = 'ҷ繻ª';
$string['ciq4'] = 'áз㴢ͧؤ㹡дҹǹ سҷسѺʹǷش?';
$string['ciq4short'] = 'ҷѺʹ';
$string['ciq5'] = '˵ءó㴷سзѺ㨷ش?';
$string['ciq5short'] = 'ҷš';
$string['ciqintro'] = 'ôͺӶҧҧ';
$string['ciqname'] = '˵ءóԡĵ';
$string['clicktocontinue'] = ' ͷӵ';
$string['clicktocontinuecheck'] = '͵Ǩ зӵ';
$string['colles1'] = '¹鹻繷ʹ繡ǹ';
$string['colles10'] = 'ѡ¹蹢ǤԴ';
$string['colles10short'] = 'ͤ͸Ժ';
$string['colles11'] = 'ѡ¹蹢ѹǤԴ';
$string['colles11short'] = 'դѩѹ͸Ժ';
$string['colles12'] = 'ѡ¹蹵ͺѺԴ';
$string['colles12short'] = 'ѡ¹蹵ͺѺѹ';
$string['colles13'] = '͹¡е鹤Դ';
$string['colles13short'] = '͹¡е鹤Դ';
$string['colles14'] = '͹ʹѺʹعǹ';
$string['colles14short'] = '͹ʹѺʹعǹ';
$string['colles15'] = '͹͡Ẻʹ';
$string['colles15short'] = '͹͡Ẻʹ';
$string['colles16'] = '͹͡ẺԨͧ';
$string['colles16short'] = '͹͡ẺԨͧ';
$string['colles17'] = 'ѡ¹ʹѺʹعǹ';
$string['colles17short'] = 'ѡ¹ʹѺʹع';
$string['colles18'] = 'ѡ¹¡ͧ';
$string['colles18short'] = 'ѡ¹¡ͧ';
$string['colles19'] = 'ѡ¹繤سҢͧ';
$string['colles19short'] = 'ѡ¹繤س';
$string['colles1short'] = '㹻繷ʹ';
$string['colles2'] = '觷¹ դӤѭ͡ý֡ԪҪվ';
$string['colles20'] = 'ѡ¹㹤';
$string['colles20short'] = 'ѡ¹';
$string['colles21'] = 'ѹͷѡ¹蹹ʹ';
$string['colles21short'] = 'ѹ㨹ѡ¹';
$string['colles22'] = 'ѡ¹ͷʹ';
$string['colles22short'] = 'ѡ¹㨩ѹ';
$string['colles23'] = 'ѹͷ͹ʹ';
$string['colles23short'] = 'ѹ㨼͹';
$string['colles24'] = '͹ͷʹ';
$string['colles24short'] = '͹㨩ѹ';
$string['colles2short'] = 'Ӥѭ͡ý֡Ѵ';
$string['colles3'] = '觷¹դӤѭ͡ý֡ԪҪվ';
$string['colles3short'] = 'Ѳҡý֡Ѵ';
$string['colles4'] = '觷¹ ǹǢͧѺý֡ԪҪվ';
$string['colles4short'] = 'ǢͧѺý֡ԪҪվ';
$string['colles5'] = 'ԴҡͧԸա¹';
$string['colles5short'] = '´㹡¹';
$string['colles6'] = 'ԴҡͧԴǹ';
$string['colles6short'] = '´㹤ǹ';
$string['colles7'] = 'ԴҡͧԴ繢ͧѡ¹';
$string['colles7short'] = '´ͧѡ¹';
$string['colles8'] = '´ͧԴ觷ҹ';
$string['colles8short'] = '´觷ҹ';
$string['colles9'] = '͸Ժ¤Դǹѡ¹';
$string['colles9short'] = '͸Ժ¤Դǹ';
$string['collesaintro'] = 'Ǩըشʧͪ͡͹͹ŹЪҹ¹§

Ӷ 24 ͵仹 жͧʺóҡ÷ͧҹѧ

դӵͺ &#8220;١&#8221;  &#8220;Դ&#8221; оԨó੾ФԴҹ鹤ӵͺͧҹж١繤Ѻ Шռŵ͡ûԹͧҹ

ӵͺͧҹǹ¾ѲٻẺͧ͡¹͹͹Ź͹Ҥ

ͺسҡ';
$string['collesaname'] = 'COLLES (Actual)';
$string['collesapintro'] = 'Ǩըشʧͪ͡͹͹ŹЪҹ¹§

Ӷ 24 ͵仹 жºº֧ <b>ͺ<b> (㹤Դ)  <b>֡ԧ<b> ҡ÷ͧҹ

դӵͺ &#8220;١&#8221;  &#8220;Դ&#8221; оԨó੾ФԴҹ鹤ӵͺͧҹж١繤Ѻ Шռŵ͡ûԹͧҹ

ӵͺͧҹǹ¾ѲٻẺͧ͡¹͹͹Ź͹Ҥ

ͺسҡ';
$string['collesapname'] = 'COLLES (Preferred and Actual)';
$string['collesm1'] = 'Ǣͧ';
$string['collesm1short'] = 'Ǣͧ';
$string['collesm2'] = 'Ԩͧ';
$string['collesm2short'] = 'Ԩͧ';
$string['collesm3'] = 'Ԩѹ';
$string['collesm3short'] = 'Ԩѹ';
$string['collesm4'] = 'ͨҡ͹';
$string['collesm4short'] = 'ͨҡ͹';
$string['collesm5'] = 'ǢͧʹѺʹع';
$string['collesm5short'] = 'Ǣͧ';
$string['collesm6'] = '';
$string['collesm6short'] = '';
$string['collesmintro'] = '㹺¹͹Ź';
$string['collespintro'] = 'Ǩըشʧͪ㨤سҢͧʺó㹡¹ͤ͹

Ӷ 24 ͵仹 жǡѺ <b>ͺ</b>㹡õͺẺͺ

դӵͺ &#8220;١&#8221;  &#8220;Դ&#8221; оԨó੾ФԴҹ鹤ӵͺͧҹж١繤Ѻ Шռŵ͡ûԹͧҹ

ӵͺͧҹǹ¾ѲٻẺͧ͡¹͹͹Ź͹Ҥ

ͺسҡ';
$string['collespname'] = 'COLLES (Preferred)';
$string['done'] = '';
$string['download'] = 'ǹŴ';
$string['downloadexcel'] = 'ǹŴٻ ҧ Excel';
$string['downloadinfo'] = 'ҹöǹŴŴԺҡẺͺ ͡ ٻͧ Excel, SPSS ';
$string['downloadtext'] = 'ǹŴٻͧ  plain text';
$string['editingasurvey'] = 'Ẻͺ';
$string['guestsnotallowed'] = '੾Ҫԡҹ';
$string['helpsurveys'] = 'ǡѺ Ẻͺ';
$string['howlong'] = 'ҹҹҹ㹡÷Ẻͺ';
$string['howlongoptions'] = '¡ 1 ҷ, 1-2 ҷ, 2-3 ҷ, 3-4 ҷ, 4-5 ҷ, 5-10 ҷ, ҡ 10 ҷ';
$string['ifoundthat'] = 'ѹ';
$string['introtext'] = 'ͤʴͧ';
$string['ipreferthat'] = 'ѹͺҡҷ';
$string['modulename'] = 'Ẻͺ';
$string['modulenameplural'] = 'Ẻͺ';
$string['name'] = '';
$string['newsurveyresponses'] = 'šǨ ';
$string['nobodyyet'] = 'ռ㴷Ẻͺ';
$string['notdone'] = 'ѧ';
$string['notes'] = 'кѹ֡ͧҹ';
$string['othercomments'] = 'Դ';
$string['peoplecompleted'] = ' $a    Ẻͺ';
$string['preferred'] = 'ͺ';
$string['preferredclass'] = '¹ͺ';
$string['preferredstudent'] = '$a  ͺ';
$string['question'] = 'Ӷ';
$string['questions'] = 'Ӷ';
$string['questionsnotanswered'] = 'Ӷҧѧͺ';
$string['report'] = '§ҹǨ';
$string['savednotes'] = 'Ţͧҹ١ѹ֡';
$string['scaleagree5'] = '繴ҧ, 繴, դ, 繴, 繴ҧ';
$string['scales'] = '';
$string['scaletimes5'] = 'ͺ, ҡ, ҧ, , ͺʹ ';
$string['seemoredetail'] = ' ҹ´';
$string['selectedquestions'] = 'Ӷ١͡ҡ ѡ¹';
$string['summary'] = 'Ѵ';
$string['surveycompleted'] = 'سẺͺ ҿҧҧʴººѺ¢ͧ¹';
$string['surveyname'] = '͡Ǩ';
$string['surveysaved'] = 'Ǩѹ֡';
$string['surveytype'] = 'Ǩ';
$string['thanksforanswers'] = 'ͺسѺõͺẺͺ, $a';
$string['time'] = '';
$string['viewsurveyresponses'] = ' $a šǨ';

?>
